"""Defines constants for the module."""

devops_toolset_download_resource = "https://github.com/aheadlabs/devops-toolset/archive/master.zip"
devops_toolset_save_as = "devops-toolset-master.zip"
devops_toolset_folder = "devops-toolset"
project_xml_name = "project.xml"
project_xml_download_resource = "https://raw.githubusercontent.com/aheadlabs/devops-toolset/master/project.xml"
dev_branch_regex = r'(refs\/heads\/)?dev|development'
release_branch_regex = r'(refs\/heads\/)?release\/(.*)*'
main_branch_regex = r'(refs\/heads\/)?main|master'
